Core Types — sudio documentation

# Core Types

class sudio.types.enum.StreamMode(value, names=None, *, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `Enum`

  Enumeration representing different stream modes.

  normal = 0
  optimized = 1

exception sudio.types.error.RefreshError

  Bases: `Exception`

  Exception raised when a refresh operation encounters an error.

exception sudio.types.error.MiniaudioError

  Bases: `Exception`

  Base exception class for errors related to miniaudio.

exception sudio.types.error.DecodeError

  Bases: `MiniaudioError`

  Exception raised when an error occurs during audio decoding.

exception sudio.types.error.StreamError

  Bases: `Exception`

  Exception raised for errors related to audio streaming.

class sudio.types.pipelineonbusytype.PipelineOnBusyType(value, names=None, *, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `Enum`

  Enumeration representing different Pipeline Process Types

  DROP = 0
  BLOCK = 1

class sudio.types.pipelineprocesstype.PipelineProcessType(value, names=None, *, module=None, qualname=None, type=None, start=1, boundary=None)

  Bases: `Enum`

  Enumeration representing different Pipeline Process Types

  MAIN = 0
  MULTI_STREAM = 1
  BRANCH = 2
  QUEUE = 3